@@ -1,7 +1,7 @@
 from typing import Optional, Any, NoReturn, Dict, List
 
-from .exceptions import InvalidName
-from .command import Command, COMMANDS
+from pymongolite.exceptions import InvalidName
+from pymongolite.backend.command import Command, COMMANDS
 
 
 class Collection:
@@ -103,7 +103,7 @@ class Collection:
                     collection_name=self.__name,
                     documents=[doc],
                 ),
-            )
+            )[0]
 
     def insert_many(self, docs: List[Dict]):
         with self.__database._open_session() as session:
